@@ -2,7 +2,7 @@ import logging
 from pathlib import Path
 from typing import Dict, Any, Callable, Type
 
-__version__ = '0.0.18'
+__version__ = '0.0.19'
 
 logging.basicConfig(format='%(asctime)d-%(levelname)s-%(message)s')
 
@@ -15,4 +15,4 @@ FOLDER_DATA = Path(FOLDER_ROOT, 'data')
 
 # custom type hints
 JsonLike = Dict[str, Any] | Any
-TypeLike = Type | Callable
+TypeLike = Callable | Type
